@@ -85,7 +85,11 @@ up_path = joinpath(@__DIR__, "UsesPreferences")
         @test !haskey(prefs["UsesPreferences"], "__clear__")
 
         # Now show that it forces recompilation
-        did_precompile(output) = occursin("Precompiling UsesPreferences [$(string(up_uuid))]", output)
+        function did_precompile(output)
+            occursin("Precompiling UsesPreferences [$(string(up_uuid))]", output) ||
+            occursin("Precompiling\e[22m\e[39m UsesPreferences", output) ||
+            occursin(r"\e\[32m +✓ +\e\[39mUsesPreferences", output)
+        end
         cuda_test = """
         using UsesPreferences, Test
         @test UsesPreferences.backend == "CUDA"
